pub fn module_kind_name(
kinds: &BTreeMap<ModuleInstanceId, String>,
id: ModuleInstanceId,
) -> &strExpand description
Look up the kind name for a module instance ID.
pub fn module_kind_name(
kinds: &BTreeMap<ModuleInstanceId, String>,
id: ModuleInstanceId,
) -> &strLook up the kind name for a module instance ID.